==> estateplat-common-1.2.4-20240412.020440-1231-sources.jar: cn/gtmap/estateplat/model/server/core/GdFw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过渡期房屋登记信息表
 *
 * @author lst
 * @version V1.0, 15-3-23
 */
@Table(name = "gd_fw")
public class GdFw implements Serializable, InsertVo {
    @Id
    private String fwid;//主键
    private String dah; //档案号
    private String gyqk;//共有情况
    private String ghyt;//规划用途
    private Double jyjg;//房地产交易价格
    private String fwxz;//房屋性质
    private String fwjg;//房屋结构
    private String szc;//所在层
    private Integer zcs;//总层数
    private Double tnjzmj;//套内建筑面积
    private Date jgsj;//竣工时间
    private String fwzl;//房屋坐落
    private String dw;//单位
    private Double jzmj;//建筑面积
    private String fjh;//房间号

    private Double ftjzmj;//分摊建筑面积


    private String cqly;//产权来源
    private String fwlx;//房屋类型

    private String sjly;//数据来源
    private String fwDcbIndex;//逻辑幢主键
    private Date gxrq;//更新日期
    private String qlid;//权利id
    private String zrzh;//自然幢号
    private String dwdm;//单位单面
    private String bz;//备注
    private String isfsss;//是否附属设施
    private String pth;//配图号

    private String myzcs;//名义总层数
    private Double cg;//层高

    private Double scmj;//实测面积

    private String dwmc;//单位名称

    private String zffwbh;//主房房屋编号
    private String fwbm;//房屋编码

    private String fcdahtbh;//房产档案合同编号
    private String cjsfgl;//创建时是否过滤附属设施（1是；0或空否）

    public String getFcdahtbh() {
        return fcdahtbh;
    }

    public void setFcdahtbh(String fcdahtbh) {
        this.fcdahtbh = fcdahtbh;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getFwid() {
        return fwid;
    }

    public void setFwid(String fwid) {
        this.fwid = fwid;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }


    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQlid() {

        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss) {
        this.isfsss = isfsss;
    }

    public String getMyzcs() {
        return myzcs;
    }

    public void setMyzcs(String myzcs) {
        this.myzcs = myzcs;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getPth() {
        return pth;
    }

    public void setPth(String pth) {
        this.pth = pth;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }

    public String getZffwbh() {
        return zffwbh;
    }

    public void setZffwbh(String zffwbh) {
        this.zffwbh = zffwbh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getCjsfgl() {
        return cjsfgl;
    }

    public void setCjsfgl(String cjsfgl) {
        this.cjsfgl = cjsfgl;
    }
}

==> estateplat-common-1.2.4-20250210.014539-1281-sources.jar: cn/gtmap/estateplat/model/server/core/GdFw.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 过渡期房屋登记信息表
 *
 * @author lst
 * @version V1.0, 15-3-23
 */
@Table(name = "gd_fw")
public class GdFw implements Serializable, InsertVo {
    @Id
    private String fwid;//主键
    private String dah; //档案号
    private String gyqk;//共有情况
    private String ghyt;//规划用途
    private Double jyjg;//房地产交易价格
    private String fwxz;//房屋性质
    private String fwjg;//房屋结构
    private String szc;//所在层
    private Integer zcs;//总层数
    private Double tnjzmj;//套内建筑面积
    private Date jgsj;//竣工时间
    private String fwzl;//房屋坐落
    private String dw;//单位
    private Double jzmj;//建筑面积
    private String fjh;//房间号

    private Double ftjzmj;//分摊建筑面积


    private String cqly;//产权来源
    private String fwlx;//房屋类型

    private String sjly;//数据来源
    private String fwDcbIndex;//逻辑幢主键
    private Date gxrq;//更新日期
    private String qlid;//权利id
    private String zrzh;//自然幢号
    private String dwdm;//单位单面
    private String bz;//备注
    private String isfsss;//是否附属设施
    private String pth;//配图号

    private String myzcs;//名义总层数
    private Double cg;//层高

    private Double scmj;//实测面积

    private String dwmc;//单位名称

    private String zffwbh;//主房房屋编号
    private String fwbm;//房屋编码

    private String fcdahtbh;//房产档案合同编号
    private String cjsfgl;//创建时是否过滤附属设施（1是；0或空否）

    // 土地用途
    private String tdyt;

    public String getFcdahtbh() {
        return fcdahtbh;
    }

    public void setFcdahtbh(String fcdahtbh) {
        this.fcdahtbh = fcdahtbh;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getFwid() {
        return fwid;
    }

    public void setFwid(String fwid) {
        this.fwid = fwid;
    }

    public String getDah() {
        return dah;
    }

    public void setDah(String dah) {
        this.dah = dah;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public Integer getZcs() {
        return zcs;
    }

    public void setZcs(Integer zcs) {
        this.zcs = zcs;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getTnjzmj() {
        return tnjzmj;
    }

    public void setTnjzmj(Double tnjzmj) {
        this.tnjzmj = tnjzmj;
    }

    public Double getFtjzmj() {
        return ftjzmj;
    }

    public void setFtjzmj(Double ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }


    public String getFwDcbIndex() {
        return fwDcbIndex;
    }

    public void setFwDcbIndex(String fwDcbIndex) {
        this.fwDcbIndex = fwDcbIndex;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQlid() {

        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIsfsss() {
        return isfsss;
    }

    public void setIsfsss(String isfsss) {
        this.isfsss = isfsss;
    }

    public String getMyzcs() {
        return myzcs;
    }

    public void setMyzcs(String myzcs) {
        this.myzcs = myzcs;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getPth() {
        return pth;
    }

    public void setPth(String pth) {
        this.pth = pth;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }

    public String getZffwbh() {
        return zffwbh;
    }

    public void setZffwbh(String zffwbh) {
        this.zffwbh = zffwbh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public String getCjsfgl() {
        return cjsfgl;
    }

    public void setCjsfgl(String cjsfgl) {
        this.cjsfgl = cjsfgl;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }
}
